@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : DarkIce.cpp
-   Version  : $Revision: 1.37 $
+   Version  : $Revision: 1.43 $
    Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/DarkIce.cpp,v $
    
@@ -97,7 +97,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: DarkIce.cpp,v 1.37 2004/02/15 12:14:38 darkeye Exp $";
+static const char fileid[] = "$Id: DarkIce.cpp,v 1.43 2005/04/11 19:27:43 darkeye Exp $";
 
 
 /*------------------------------------------------------------------------------
@@ -129,6 +129,7 @@ DarkIce :: init ( const Config      & config )              throw ( Exception )
     unsigned int             sampleRate;
     unsigned int             bitsPerSample;
     unsigned int             channel;
+    bool                     reconnect;
     const char             * device;
 
     // the [general] section
@@ -139,6 +140,8 @@ DarkIce :: init ( const Config      & config )              throw ( Exception )
     duration = Util::strToL( str);
     str = cs->getForSure( "bufferSecs", " missing in section [general]");
     bufferSecs = Util::strToL( str);
+    str           = cs->get( "reconnect");
+    reconnect     = str ? (Util::strEq( str, "yes") ? true : false) : true;
 
 
     // the [input] section
@@ -146,19 +149,19 @@ DarkIce :: init ( const Config      & config )              throw ( Exception )
         throw Exception( __FILE__, __LINE__, "no section [general] in config");
     }
     
-    str = cs->getForSure( "sampleRate", " missing in section [input]");
+    str        = cs->getForSure( "sampleRate", " missing in section [input]");
     sampleRate = Util::strToL( str);
-    str = cs->getForSure( "bitsPerSample", " missing in section [input]");
+    str       = cs->getForSure( "bitsPerSample", " missing in section [input]");
     bitsPerSample = Util::strToL( str);
-    str = cs->getForSure( "channel", " missing in section [input]");
-    channel = Util::strToL( str);
-    device = cs->getForSure( "device", " missing in section [input]");
+    str           = cs->getForSure( "channel", " missing in section [input]");
+    channel       = Util::strToL( str);
+    device        = cs->getForSure( "device", " missing in section [input]");
 
     dsp             = AudioSource::createDspSource( device,
                                                     sampleRate,
                                                     bitsPerSample,
                                                     channel );
-    encConnector    = new MultiThreadedConnector( dsp.get());
+    encConnector    = new MultiThreadedConnector( dsp.get(), reconnect );
 
     noAudioOuts = 0;
     configIceCast( config, bufferSecs);
@@ -242,7 +245,7 @@ DarkIce :: configIceCast (  const Config      & config,
                 throw Exception( __FILE__, __LINE__,
                                  "bitrate not specified for CBR encoding");
             }
-            if ( quality == 0 ) {
+            if ( cs->get( "quality" ) == 0 ) {
                 throw Exception( __FILE__, __LINE__,
                                  "quality not specified for CBR encoding");
             }
@@ -256,7 +259,7 @@ DarkIce :: configIceCast (  const Config      & config,
         } else if ( Util::strEq( str, "vbr") ) {
             bitrateMode = AudioEncoder::vbr;
 
-            if ( quality == 0 ) {
+            if ( cs->get( "quality" ) == 0 ) {
                 throw Exception( __FILE__, __LINE__,
                                  "quality not specified for VBR encoding");
             }
@@ -430,7 +433,7 @@ DarkIce :: configIceCast2 (  const Config      & config,
         } else if ( Util::strEq( str, "vbr") ) {
             bitrateMode = AudioEncoder::vbr;
 
-            if ( quality == 0 ) {
+            if ( cs->get( "quality" ) == 0 ) {
                 throw Exception( __FILE__, __LINE__,
                                  "quality not specified for VBR encoding");
             }
@@ -617,7 +620,7 @@ DarkIce :: configShoutCast (    const Config      & config,
                 throw Exception( __FILE__, __LINE__,
                                  "bitrate not specified for CBR encoding");
             }
-            if ( quality == 0 ) {
+            if ( cs->get( "quality" ) == 0 ) {
                 throw Exception( __FILE__, __LINE__,
                                  "quality not specified for CBR encoding");
             }
@@ -631,7 +634,7 @@ DarkIce :: configShoutCast (    const Config      & config,
         } else if ( Util::strEq( str, "vbr") ) {
             bitrateMode = AudioEncoder::vbr;
 
-            if ( quality == 0 ) {
+            if ( cs->get( "quality" ) == 0 ) {
                 throw Exception( __FILE__, __LINE__,
                                  "quality not specified for VBR encoding");
             }
@@ -778,7 +781,7 @@ DarkIce :: configFileCast (  const Config      & config )
                 throw Exception( __FILE__, __LINE__,
                                  "bitrate not specified for CBR encoding");
             }
-            if ( quality == 0 ) {
+            if ( cs->get( "quality" ) == 0 ) {
                 throw Exception( __FILE__, __LINE__,
                                  "quality not specified for CBR encoding");
             }
@@ -792,7 +795,7 @@ DarkIce :: configFileCast (  const Config      & config )
         } else if ( Util::strEq( str, "vbr") ) {
             bitrateMode = AudioEncoder::vbr;
 
-            if ( quality == 0 ) {
+            if ( cs->get( "quality" ) == 0 ) {
                 throw Exception( __FILE__, __LINE__,
                                  "quality not specified for VBR encoding");
             }
@@ -873,6 +876,8 @@ DarkIce :: configFileCast (  const Config      & config )
 void
 DarkIce :: setRealTimeScheduling ( void )               throw ( Exception )
 {
+// Only if the OS has the POSIX real-time scheduling functions implemented.
+#if defined( HAVE_SCHED_GETSCHEDULER ) && defined( HAVE_SCHED_GETPARAM )
     uid_t   euid;
 
     euid = geteuid();
@@ -917,6 +922,10 @@ DarkIce :: setRealTimeScheduling ( void )               throw ( Exception )
         reportEvent( 1,
         "It is recommended that you run this program as super-user");
     }
+#else
+    reportEvent( 1, "POSIX scheduling not supported on this system, "
+                    "this may cause recording skips");
+#endif // HAVE_SCHED_GETSCHEDULER && HAVE_SCHED_GETPARAM
 }
 
 
@@ -928,6 +937,8 @@ DarkIce :: setRealTimeScheduling ( void )               throw ( Exception )
 void
 DarkIce :: setOriginalScheduling ( void )               throw ( Exception )
 {
+// Only if the OS has the POSIX real-time scheduling functions implemented.
+#if defined( HAVE_SCHED_GETSCHEDULER ) && defined( HAVE_SCHED_GETPARAM )
     uid_t   euid;
 
     euid = geteuid();
@@ -947,6 +958,7 @@ DarkIce :: setOriginalScheduling ( void )               throw ( Exception )
 
         reportEvent( 5, "reverted to original scheduling");
     }
+#endif // HAVE_SCHED_GETSCHEDULER && HAVE_SCHED_GETPARAM
 }
 
 
@@ -999,6 +1011,26 @@ DarkIce :: run ( void )                             throw ( Exception )
   $Source: /cvsroot/darkice/darkice/src/DarkIce.cpp,v $
 
   $Log: DarkIce.cpp,v $
+  Revision 1.43  2005/04/11 19:27:43  darkeye
+  added option to turn off automatic reconnect feature
+
+  Revision 1.42  2005/04/04 08:36:17  darkeye
+  commited changes to enable Jack support
+  thanks to Nicholas J. Humfrey, njh@ecs.soton.ac.uk
+
+  Revision 1.41  2005/04/03 05:12:20  jbebel
+  Changed mechanism for testing the presence of the quality value such that
+  zero is a valid option.
+
+  Revision 1.40  2004/02/23 19:12:51  darkeye
+  ported to NetBSD
+
+  Revision 1.39  2004/02/19 06:47:06  darkeye
+  finalized OpenBSD port
+
+  Revision 1.38  2004/02/18 21:08:11  darkeye
+  ported to OpenBSD (real-time scheduling not yet supported)
+
   Revision 1.37  2004/02/15 12:14:38  darkeye
   added patch to allow mp3 stream downsampling to mono for icecast2 as well
 
